var __assign = Object.assign;

// src/injectHtml.ts
import {render} from "ejs";
function injectHtml(options = {}) {
  return {
    name: "vite:injectHtml",
    transformIndexHtml: {
      enforce: "pre",
      transform(html) {
        const {injectData = {}, injectOptions = {}, tags = []} = options;
        return {
          html: render(html, injectData, injectOptions),
          tags
        };
      }
    }
  };
}

// src/minifyHtml.ts
import {minify} from "html-minifier-terser";
import fs from "fs-extra";
import path from "path";
import {normalizePath} from "vite";
function minifyHtml(minifyOptions = true) {
  let config;
  return {
    name: "vite:minifyHtml",
    configResolved(resolvedConfig) {
      config = resolvedConfig;
    },
    async closeBundle() {
      if (!minifyOptions) {
        return;
      }
      const defaultMinifyOptions = __assign({
        collapseBooleanAttributes: true,
        collapseWhitespace: true,
        minifyCSS: true,
        minifyJS: true,
        minifyURLs: true,
        removeAttributeQuotes: true,
        removeComments: true,
        removeEmptyAttributes: true
      }, typeof minifyOptions === "boolean" ? {} : minifyOptions);
      const {root, build} = config;
      const {outDir} = build;
      const indexHtmlPath = normalizePath(path.resolve(root, outDir, "index.html"));
      if (!fs.existsSync(indexHtmlPath)) {
        console.log("no such file: " + indexHtmlPath);
        return;
      }
      let processHtml = fs.readFileSync(indexHtmlPath, "utf-8");
      processHtml = minify(processHtml, defaultMinifyOptions);
      fs.writeFileSync(indexHtmlPath, processHtml);
    }
  };
}

// src/index.ts
var src_default = (options = {}) => {
  const {inject = {}, minify: minify2 = {}} = options;
  return [injectHtml(inject), minifyHtml(minify2)];
};
export {
  src_default as default,
  injectHtml,
  minifyHtml
};
